import os

def generate_index_html(directory, output_file):
    with open(output_file, "w") as f:
        f.write("<html>\n<head><title>Directory Index</title></head>\n<body>\n")
        f.write(f"<h1>Index of {directory}</h1>\n")
        f.write("<ul>\n")
        generate_directory_listing(directory, f, directory)
        f.write("</ul>\n</body>\n</html>")

def generate_directory_listing(current_directory, f, base_directory):
    for item in sorted(os.listdir(current_directory)):
        if item.startswith("."):
            continue  # Skip hidden files and directories
        item_path = os.path.join(current_directory, item)
        relative_path = os.path.relpath(item_path, base_directory)
        if os.path.isdir(item_path):
            f.write(f"<li><strong>Directory: <a href='{relative_path}/index.html'>{item}</a></strong></li>\n")
            f.write("<ul>\n")
            # Recursively generate index.html in each subdirectory
            subdirectory_index_path = os.path.join(item_path, "index.html")
            generate_index_html(item_path, subdirectory_index_path)
            generate_directory_listing(item_path, f, base_directory)
            f.write("</ul>\n")
        else:
            f.write(f"<li><a href='{relative_path}'>{item}</a></li>\n")

if __name__ == "__main__":
    base_directory = "./"  # Change this to the directory you want to index
    output_file = os.path.join(base_directory, "index.html")
    generate_index_html(base_directory, output_file)
    print(f"Index file generated at: {output_file}")
